pub struct GoogleCloudDialogflowV2AgentAssistantFeedback {
pub answer_relevance: Option<String>,
pub document_correctness: Option<String>,
pub document_efficiency: Option<String>,
pub knowledge_assist_feedback: Option<GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeAssistFeedback>,
pub knowledge_search_feedback: Option<GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeSearchFeedback>,
pub summarization_feedback: Option<GoogleCloudDialogflowV2AgentAssistantFeedbackSummarizationFeedback>,
}Expand description
Detail feedback of Agent Assist result.
This type is not used in any activity, and only used as part of another schema.
Fields
answer_relevance: Option<String>Optional. Whether or not the suggested answer is relevant. For example: * Query: “Can I change my mailing address?” * Suggested document says: “Items must be returned/exchanged within 60 days of the purchase date.” * answer_relevance: AnswerRelevance.IRRELEVANT
document_correctness: Option<String>Optional. Whether or not the information in the document is correct. For example: * Query: “Can I return the package in 2 days once received?” * Suggested document says: “Items must be returned/exchanged within 60 days of the purchase date.” * Ground truth: “No return or exchange is allowed.” * [document_correctness]: INCORRECT
document_efficiency: Option<String>Optional. Whether or not the suggested document is efficient. For example, if the document is poorly written, hard to understand, hard to use or too long to find useful information, document_efficiency is DocumentEfficiency.INEFFICIENT.
knowledge_assist_feedback: Option<GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeAssistFeedback>Optional. Feedback for knowledge assist.
knowledge_search_feedback: Option<GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeSearchFeedback>Optional. Feedback for knowledge search.
summarization_feedback: Option<GoogleCloudDialogflowV2AgentAssistantFeedbackSummarizationFeedback>Optional. Feedback for conversation summarization.