GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeSearchFeedback

Struct GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeSearchFeedback 

pub struct GoogleCloudDialogflowV2AgentAssistantFeedbackKnowledgeSearchFeedback {
    pub answer_copied: Option<bool>,
    pub clicked_uris: Option<Vec<String>>,
}
Feedback for knowledge search.

This type is not used in any activity, and only used as part of another schema.

Fields

answer_copied: Option<bool>

Whether the answer was copied by the human agent or not. If the value is set to be true, AnswerFeedback.clicked will be updated to be true.

clicked_uris: Option<Vec<String>>

The URIs clicked by the human agent. The value is appended for each UpdateAnswerRecordRequest. If the value is not empty, AnswerFeedback.clicked will be updated to be true.