pub struct GoogleCloudDialogflowV2AgentAssistantRecord {
pub article_suggestion_answer: Option<GoogleCloudDialogflowV2ArticleAnswer>,
pub dialogflow_assist_answer: Option<GoogleCloudDialogflowV2DialogflowAssistAnswer>,
pub faq_answer: Option<GoogleCloudDialogflowV2FaqAnswer>,
}Expand description
Represents a record of a human agent assist answer.
This type is not used in any activity, and only used as part of another schema.
Fields
article_suggestion_answer: Option<GoogleCloudDialogflowV2ArticleAnswer>Output only. The article suggestion answer.
dialogflow_assist_answer: Option<GoogleCloudDialogflowV2DialogflowAssistAnswer>Output only. Dialogflow assist answer.
faq_answer: Option<GoogleCloudDialogflowV2FaqAnswer>Output only. The FAQ answer.