Struct google_dialogflow2::api::GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest[][src]

pub struct GoogleCloudDialogflowV2BatchUpdateEntityTypesRequest {
    pub entity_type_batch_inline: Option<GoogleCloudDialogflowV2EntityTypeBatch>,
    pub entity_type_batch_uri: Option<String>,
    pub language_code: Option<String>,
    pub update_mask: Option<String>,
}

The request message for EntityTypes.BatchUpdateEntityTypes.

Activities

This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).

Fields

entity_type_batch_inline: Option<GoogleCloudDialogflowV2EntityTypeBatch>

The collection of entity types to update or create.

entity_type_batch_uri: Option<String>

The URI to a Google Cloud Storage file containing entity types to update or create. The file format can either be a serialized proto (of EntityBatch type) or a JSON object. Note: The URI must start with “gs://”.

language_code: Option<String>

Optional. The language used to access language-specific data. If not specified, the agent’s default language is used. For more information, see Multilingual intent and entity data.

update_mask: Option<String>

Optional. The mask to control which fields get updated.