pub struct GoogleCloudDialogflowV2DtmfParameters {
pub accepts_dtmf_input: Option<bool>,
}Expand description
The message in the response that indicates the parameters of DTMF.
This type is not used in any activity, and only used as part of another schema.
Fields
accepts_dtmf_input: Option<bool>Indicates whether DTMF input can be handled in the next request.