Struct google_dialogflow2::api::GoogleCloudDialogflowV2EntityTypeEntity [−][src]
An entity entry for an associated entity type.
This type is not used in any activity, and only used as part of another schema.
Fields
synonyms: Option<Vec<String>>Required. A collection of value synonyms. For example, if the entity type is vegetable, and value is scallions, a synonym could be green onions. For KIND_LIST entity types: * This collection must contain exactly one synonym equal to value.
value: Option<String>Required. The primary value associated with this entity entry. For example, if the entity type is vegetable, the value could be scallions. For KIND_MAP entity types: * A reference value to be used in place of synonyms. For KIND_LIST entity types: * A string that can contain references to other entity types (with or without aliases).