pub struct GoogleCloudDialogflowV2FulfillmentFeature {
pub type_: Option<String>,
}Expand description
Whether fulfillment is enabled for the specific feature.
This type is not used in any activity, and only used as part of another schema.
Fields
type_: Option<String>The type of the feature that enabled for fulfillment.