pub struct GoogleCloudDialogflowV2GcsSources {
pub uris: Option<Vec<String>>,
}Expand description
Google Cloud Storage location for the inputs.
This type is not used in any activity, and only used as part of another schema.
Fields
uris: Option<Vec<String>>Required. Google Cloud Storage URIs for the inputs. A URI is of the form: gs://bucket/object-prefix-or-name Whether a prefix or name is used depends on the use case.