pub struct GoogleCloudDialogflowV2GenerateStatelessSuggestionResponse {
pub generator_suggestion: Option<GoogleCloudDialogflowV2GeneratorSuggestion>,
}Expand description
The response message for Conversations.GenerateStatelessSuggestion.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
generator_suggestion: Option<GoogleCloudDialogflowV2GeneratorSuggestion>Required. Generated suggestion for a conversation.