pub struct GoogleCloudDialogflowV2GenerateStatelessSummaryResponse {
pub context_size: Option<i32>,
pub latest_message: Option<String>,
pub summary: Option<GoogleCloudDialogflowV2GenerateStatelessSummaryResponseSummary>,
}Expand description
The response message for Conversations.GenerateStatelessSummary.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
context_size: Option<i32>Number of messages prior to and including last_conversation_message used to compile the suggestion. It may be smaller than the GenerateStatelessSummaryRequest.context_size field in the request if there weren’t that many messages in the conversation.
latest_message: Option<String>The name of the latest conversation message used as context for compiling suggestion. The format is specific to the user and the names of the messages provided.
summary: Option<GoogleCloudDialogflowV2GenerateStatelessSummaryResponseSummary>Generated summary.