pub struct GoogleCloudDialogflowV2HumanAgentHandoffConfigSalesforceLiveAgentConfig {
pub button_id: Option<String>,
pub deployment_id: Option<String>,
pub endpoint_domain: Option<String>,
pub organization_id: Option<String>,
}Expand description
Configuration specific to Salesforce Live Agent.
This type is not used in any activity, and only used as part of another schema.
Fields
Required. Live Agent chat button ID.
deployment_id: Option<String>Required. Live Agent deployment ID.
endpoint_domain: Option<String>Required. Domain of the Live Agent endpoint for this agent. You can find the endpoint URL in the Live Agent settings page. For example if URL has the form https://d.la4-c2-phx.salesforceliveagent.com/…, you should fill in d.la4-c2-phx.salesforceliveagent.com.
organization_id: Option<String>Required. The organization ID of the Salesforce account.