pub struct GoogleCloudDialogflowV2IntentMessageImage {
pub accessibility_text: Option<String>,
pub image_uri: Option<String>,
}Expand description
The image response message.
This type is not used in any activity, and only used as part of another schema.
Fields
accessibility_text: Option<String>Optional. A text description of the image to be used for accessibility, e.g., screen readers.
image_uri: Option<String>Optional. The public URI to an image file.