pub struct GoogleCloudDialogflowV2ListDocumentsResponse {
pub documents: Option<Vec<GoogleCloudDialogflowV2Document>>,
pub next_page_token: Option<String>,
}Expand description
Response message for Documents.ListDocuments.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent knowledge bases documents list projects (response)
- knowledge bases documents list projects (response)
- locations knowledge bases documents list projects (response)
Fields
documents: Option<Vec<GoogleCloudDialogflowV2Document>>The list of documents.
next_page_token: Option<String>Token to retrieve the next page of results, or empty if there are no more results in the list.