pub struct GoogleCloudDialogflowV2NotificationConfig {
pub message_format: Option<String>,
pub topic: Option<String>,
}Expand description
Defines notification behavior.
This type is not used in any activity, and only used as part of another schema.
Fields
message_format: Option<String>Format of message.
topic: Option<String>Name of the Pub/Sub topic to publish conversation events like CONVERSATION_STARTED as serialized ConversationEvent protos. For telephony integration to receive notification, make sure either this topic is in the same project as the conversation or you grant service-@gcp-sa-dialogflow.iam.gserviceaccount.com the Dialogflow Service Agent role in the topic project. For chat integration to receive notification, make sure API caller has been granted the Dialogflow Service Agent role for the topic. Format: projects//locations//topics/.