pub struct GoogleCloudDialogflowV2SuggestFaqAnswersResponse {
pub context_size: Option<i32>,
pub faq_answers: Option<Vec<GoogleCloudDialogflowV2FaqAnswer>>,
pub latest_message: Option<String>,
}Expand description
The request message for Participants.SuggestFaqAnswers.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
context_size: Option<i32>Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestFaqAnswersRequest.context_size field in the request if there aren’t that many messages in the conversation.
faq_answers: Option<Vec<GoogleCloudDialogflowV2FaqAnswer>>Answers extracted from FAQ documents.
latest_message: Option<String>The name of the latest conversation message used to compile suggestion for. Format: projects//locations//conversations//messages/.