pub struct GoogleCloudDialogflowV2SuggestKnowledgeAssistRequest {
pub context_size: Option<i32>,
pub latest_message: Option<String>,
pub previous_suggested_query: Option<String>,
}Expand description
The request message for Participants.SuggestKnowledgeAssist.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
context_size: Option<i32>Optional. Max number of messages prior to and including latest_message to use as context when compiling the suggestion. The context size is by default 100 and at most 100.
latest_message: Option<String>Optional. The name of the latest conversation message to compile suggestions for. If empty, it will be the latest message of the conversation. Format: projects//locations//conversations//messages/.
previous_suggested_query: Option<String>Optional. The previously suggested query for the given conversation. This helps identify whether the next suggestion we generate is resonably different from the previous one. This is useful to avoid similar suggestions within the conversation.