pub struct GoogleCloudDialogflowV2SuggestSmartRepliesRequest {
pub context_size: Option<i32>,
pub current_text_input: Option<GoogleCloudDialogflowV2TextInput>,
pub latest_message: Option<String>,
}Expand description
The request message for Participants.SuggestSmartReplies.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
context_size: Option<i32>Max number of messages prior to and including [latest_message] to use as context when compiling the suggestion. By default 20 and at most 50.
current_text_input: Option<GoogleCloudDialogflowV2TextInput>The current natural language text segment to compile suggestion for. This provides a way for user to get follow up smart reply suggestion after a smart reply selection, without sending a text message.
latest_message: Option<String>The name of the latest conversation message to compile suggestion for. If empty, it will be the latest message of the conversation. Format: projects//locations//conversations//messages/.