pub struct GoogleCloudDialogflowV2SuggestSmartRepliesResponse {
pub context_size: Option<i32>,
pub latest_message: Option<String>,
pub smart_reply_answers: Option<Vec<GoogleCloudDialogflowV2SmartReplyAnswer>>,
}Expand description
The response message for Participants.SuggestSmartReplies.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
Fields
context_size: Option<i32>Number of messages prior to and including latest_message to compile the suggestion. It may be smaller than the SuggestSmartRepliesRequest.context_size field in the request if there aren’t that many messages in the conversation.
latest_message: Option<String>The name of the latest conversation message used to compile suggestion for. Format: projects//locations//conversations//messages/.
smart_reply_answers: Option<Vec<GoogleCloudDialogflowV2SmartReplyAnswer>>Output only. Multiple reply options provided by smart reply service. The order is based on the rank of the model prediction. The maximum number of the returned replies is set in SmartReplyConfig.