pub struct GoogleCloudDialogflowV2TextToSpeechSettings {
pub enable_text_to_speech: Option<bool>,
pub output_audio_encoding: Option<String>,
pub sample_rate_hertz: Option<i32>,
pub synthesize_speech_configs: Option<HashMap<String, GoogleCloudDialogflowV2SynthesizeSpeechConfig>>,
}Expand description
Instructs the speech synthesizer on how to generate the output audio content.
This type is not used in any activity, and only used as part of another schema.
Fields
enable_text_to_speech: Option<bool>Optional. Indicates whether text to speech is enabled. Even when this field is false, other settings in this proto are still retained.
output_audio_encoding: Option<String>Required. Audio encoding of the synthesized audio content.
sample_rate_hertz: Option<i32>Optional. The synthesis sample rate (in hertz) for this audio. If not provided, then the synthesizer will use the default sample rate based on the audio encoding. If this is different from the voice’s natural sample rate, then the synthesizer will honor this request by converting to the desired sample rate (which might result in worse audio quality).
synthesize_speech_configs: Option<HashMap<String, GoogleCloudDialogflowV2SynthesizeSpeechConfig>>Optional. Configuration of how speech should be synthesized, mapping from language (https://cloud.google.com/dialogflow/docs/reference/language) to SynthesizeSpeechConfig.