pub struct GoogleLongrunningOperation {
pub done: Option<bool>,
pub error: Option<GoogleRpcStatus>,
pub metadata: Option<HashMap<String, Value>>,
pub name: Option<String>,
pub response: Option<HashMap<String, Value>>,
}Expand description
This resource represents a long-running operation that is the result of a network API call.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent entity types entities batch create projects (response)
- agent entity types entities batch delete projects (response)
- agent entity types entities batch update projects (response)
- agent entity types batch delete projects (response)
- agent entity types batch update projects (response)
- agent intents batch delete projects (response)
- agent intents batch update projects (response)
- agent knowledge bases documents create projects (response)
- agent knowledge bases documents delete projects (response)
- agent knowledge bases documents patch projects (response)
- agent knowledge bases documents reload projects (response)
- agent export projects (response)
- agent import projects (response)
- agent restore projects (response)
- agent train projects (response)
- conversation datasets import conversation data projects (response)
- conversation models create projects (response)
- conversation models delete projects (response)
- conversation models deploy projects (response)
- conversation models undeploy projects (response)
- conversation profiles clear suggestion feature config projects (response)
- conversation profiles set suggestion feature config projects (response)
- knowledge bases documents create projects (response)
- knowledge bases documents delete projects (response)
- knowledge bases documents export projects (response)
- knowledge bases documents import projects (response)
- knowledge bases documents patch projects (response)
- knowledge bases documents reload projects (response)
- locations agent entity types entities batch create projects (response)
- locations agent entity types entities batch delete projects (response)
- locations agent entity types entities batch update projects (response)
- locations agent entity types batch delete projects (response)
- locations agent entity types batch update projects (response)
- locations agent intents batch delete projects (response)
- locations agent intents batch update projects (response)
- locations agent export projects (response)
- locations agent import projects (response)
- locations agent restore projects (response)
- locations agent train projects (response)
- locations conversation datasets create projects (response)
- locations conversation datasets delete projects (response)
- locations conversation datasets import conversation data projects (response)
- locations conversation models evaluations create projects (response)
- locations conversation models create projects (response)
- locations conversation models delete projects (response)
- locations conversation models deploy projects (response)
- locations conversation models undeploy projects (response)
- locations conversation profiles clear suggestion feature config projects (response)
- locations conversation profiles set suggestion feature config projects (response)
- locations knowledge bases documents create projects (response)
- locations knowledge bases documents delete projects (response)
- locations knowledge bases documents export projects (response)
- locations knowledge bases documents import projects (response)
- locations knowledge bases documents patch projects (response)
- locations knowledge bases documents reload projects (response)
- locations operations get projects (response)
- operations get projects (response)
Fields
done: Option<bool>If the value is false, it means the operation is still in progress. If true, the operation is completed, and either error or response is available.
error: Option<GoogleRpcStatus>The error result of the operation in case of failure or cancellation.
metadata: Option<HashMap<String, Value>>Service-specific metadata associated with the operation. It typically contains progress information and common metadata such as create time. Some services might not provide such metadata. Any method that returns a long-running operation should document the metadata type, if any.
name: Option<String>The server-assigned name, which is only unique within the same service that originally returns it. If you use the default HTTP mapping, the name should be a resource name ending with operations/{unique_id}.
response: Option<HashMap<String, Value>>The normal, successful response of the operation. If the original method returns no data on success, such as Delete, the response is google.protobuf.Empty. If the original method is standard Get/Create/Update, the response should be the resource. For other methods, the response should have the type XxxResponse, where Xxx is the original method name. For example, if the original method name is TakeSnapshot(), the inferred response type is TakeSnapshotResponse.