[−][src]Struct google_dialogflow2::GoogleCloudDialogflowV2DetectIntentResponse
The message returned from the DetectIntent method.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent sessions detect intent projects (response)
Fields
output_audio: Option<String>The audio data bytes encoded as specified in the request.
Note: The output audio is generated based on the values of default platform
text responses found in the query_result.fulfillment_messages field. If
multiple default text responses exist, they will be concatenated when
generating audio. If no default platform text responses exist, the
generated audio content will be empty.
output_audio_config: Option<GoogleCloudDialogflowV2OutputAudioConfig>The config used by the speech synthesizer to generate the output audio.
webhook_status: Option<GoogleRpcStatus>Specifies the status of the webhook request.
response_id: Option<String>The unique identifier of the response. It can be used to locate a response in the training example set or for reporting issues.
query_result: Option<GoogleCloudDialogflowV2QueryResult>The selected results of the conversational query or event processing.
See alternative_query_results for additional potential results.