[−][src]Struct google_dialogflow2::GoogleCloudDialogflowV2InputAudioConfig
Instructs the speech recognizer how to process the audio content.
This type is not used in any activity, and only used as part of another schema.
Fields
language_code: Option<String>Required. The language of the supplied audio. Dialogflow does not do translations. See Language Support for a list of the currently supported language codes. Note that queries in the same session do not necessarily need to specify the same language.
audio_encoding: Option<String>Required. Audio encoding of the audio content to process.
model_variant: Option<String>Optional. Which variant of the Speech model to use.
phrase_hints: Option<Vec<String>>Optional. A list of strings containing words and phrases that the speech recognizer should recognize with higher likelihood.
See the Cloud Speech documentation for more details.
sample_rate_hertz: Option<i32>Required. Sample rate (in Hertz) of the audio content sent in the query. Refer to Cloud Speech API documentation for more details.
single_utterance: Option<bool>Optional. If false (default), recognition does not cease until the
client closes the stream.
If true, the recognizer will detect a single spoken utterance in input
audio. Recognition ceases when it detects the audio's voice has
stopped or paused. In this case, once a detected intent is received, the
client should close the stream and start a new request with a new stream as
needed.
Note: This setting is relevant only for streaming methods.
Note: When specified, InputAudioConfig.single_utterance takes precedence
over StreamingDetectIntentRequest.single_utterance.