[−][src]Struct google_dialogflow2::GoogleCloudDialogflowV2IntentMessage
Corresponds to the Response field in the Dialogflow console.
This type is not used in any activity, and only used as part of another schema.
Fields
simple_responses: Option<GoogleCloudDialogflowV2IntentMessageSimpleResponses>The voice and text-only responses for Actions on Google.
quick_replies: Option<GoogleCloudDialogflowV2IntentMessageQuickReplies>The quick replies response.
link_out_suggestion: Option<GoogleCloudDialogflowV2IntentMessageLinkOutSuggestion>The link out suggestion chip for Actions on Google.
text: Option<GoogleCloudDialogflowV2IntentMessageText>The text response.
image: Option<GoogleCloudDialogflowV2IntentMessageImage>The image response.
suggestions: Option<GoogleCloudDialogflowV2IntentMessageSuggestions>The suggestion chips for Actions on Google.
platform: Option<String>Optional. The platform that this message is intended for.
basic_card: Option<GoogleCloudDialogflowV2IntentMessageBasicCard>The basic card response for Actions on Google.
carousel_select: Option<GoogleCloudDialogflowV2IntentMessageCarouselSelect>The carousel card response for Actions on Google.
list_select: Option<GoogleCloudDialogflowV2IntentMessageListSelect>The list card response for Actions on Google.
payload: Option<HashMap<String, String>>Returns a response containing a custom, platform-specific payload. See the Intent.Message.Platform type for a description of the structure that may be required for your platform.
card: Option<GoogleCloudDialogflowV2IntentMessageCard>The card response.