Struct google_dialogflow2::GoogleCloudDialogflowV2QueryParameters[][src]

pub struct GoogleCloudDialogflowV2QueryParameters {
    pub geo_location: Option<GoogleTypeLatLng>,
    pub contexts: Option<Vec<GoogleCloudDialogflowV2Context>>,
    pub time_zone: Option<String>,
    pub reset_contexts: Option<bool>,
    pub payload: Option<HashMap<String, String>>,
    pub session_entity_types: Option<Vec<GoogleCloudDialogflowV2SessionEntityType>>,
}

Represents the parameters of the conversational query.

This type is not used in any activity, and only used as part of another schema.

Fields

Optional. The geo location of this conversational query.

Optional. The collection of contexts to be activated before this query is executed.

Optional. The time zone of this conversational query from the time zone database, e.g., America/New_York, Europe/Paris. If not provided, the time zone specified in agent settings is used.

Optional. Specifies whether to delete all contexts in the current session before the new ones are activated.

Optional. This field can be used to pass custom data into the webhook associated with the agent. Arbitrary JSON objects are supported.

Optional. Additional session entity types to replace or extend developer entity types with. The entity synonyms apply to all languages and persist for the session of this query.