Struct google_dialogflow2::api::GoogleCloudDialogflowV2EntityType [−][src]
Each intent parameter has a type, called the entity type, which dictates exactly how data from an end-user expression is extracted. Dialogflow provides predefined system entities that can match many common types of data. For example, there are system entities for matching dates, times, colors, email addresses, and so on. You can also create your own custom entities for matching custom data. For example, you could define a vegetable entity that can match the types of vegetables available for purchase with a grocery store agent. For more information, see the Entity guide.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent entity types create projects (request|response)
- agent entity types get projects (response)
- agent entity types patch projects (request|response)
- locations agent entity types create projects (request|response)
- locations agent entity types get projects (response)
- locations agent entity types patch projects (request|response)
Fields
auto_expansion_mode: Option<String>Optional. Indicates whether the entity type can be automatically expanded.
display_name: Option<String>Required. The name of the entity type.
enable_fuzzy_extraction: Option<bool>Optional. Enables fuzzy entity extraction during classification.
entities: Option<Vec<GoogleCloudDialogflowV2EntityTypeEntity>>Optional. The collection of entity entries associated with the entity type.
kind: Option<String>Required. Indicates the kind of entity type.
name: Option<String>The unique identifier of the entity type. Required for EntityTypes.UpdateEntityType and EntityTypes.BatchUpdateEntityTypes methods. Format: projects//agent/entityTypes/.