Struct google_dialogflow2::api::GoogleCloudDialogflowV2ImportAgentRequest [−][src]
The request message for Agents.ImportAgent.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent import projects (request)
- locations agent import projects (request)
Fields
agent_content: Option<String>Zip compressed raw byte content for agent.
agent_uri: Option<String>The URI to a Google Cloud Storage file containing the agent to import. Note: The URI must start with “gs://”.