Struct google_dialogflow2::GoogleCloudDialogflowV2DetectIntentRequest [−][src]
pub struct GoogleCloudDialogflowV2DetectIntentRequest {
pub input_audio: Option<String>,
pub query_input: Option<GoogleCloudDialogflowV2QueryInput>,
pub query_params: Option<GoogleCloudDialogflowV2QueryParameters>,
}The request to detect user's intent.
Activities
This type is used in activities, which are methods you may call on this type or where this type is involved in. The list links the activity name, along with information about where it is used (one of request and response).
- agent sessions detect intent projects (request)
Fields
input_audio: Option<String>
Optional. The natural language speech audio to be processed. This field
should be populated iff query_input is set to an input audio config.
A single request can contain up to 1 minute of speech audio data.
query_input: Option<GoogleCloudDialogflowV2QueryInput>
Required. The input specification. It can be set to:
-
an audio config which instructs the speech recognizer how to process the speech audio,
-
a conversational query in the form of text, or
-
an event that specifies which intent to trigger.
query_params: Option<GoogleCloudDialogflowV2QueryParameters>
Optional. The parameters of this query.